@@ -6,6 +6,28 @@ use Config;
 use Carp 'confess';
 
 # Fields
+sub file {
+  my $self = shift;
+  if (@_) {
+    $self->{file} = $_[0];
+    return $self;
+  }
+  else {
+    return $self->{file};
+  }
+}
+
+sub file_optional {
+  my $self = shift;
+  if (@_) {
+    $self->{file_optional} = $_[0];
+    return $self;
+  }
+  else {
+    return $self->{file_optional};
+  }
+}
+
 sub exported_funcs {
   my $self = shift;
   if (@_) {
@@ -72,6 +94,50 @@ sub ld_optimize {
   }
 }
 
+sub class_name {
+  my $self = shift;
+  if (@_) {
+    $self->{class_name} = $_[0];
+    return $self;
+  }
+  else {
+    return $self->{class_name};
+  }
+}
+
+sub native_include_dir {
+  my $self = shift;
+  if (@_) {
+    $self->{native_include_dir} = $_[0];
+    return $self;
+  }
+  else {
+    return $self->{native_include_dir};
+  }
+}
+
+sub native_lib_dir {
+  my $self = shift;
+  if (@_) {
+    $self->{native_lib_dir} = $_[0];
+    return $self;
+  }
+  else {
+    return $self->{native_lib_dir};
+  }
+}
+
+sub native_bin_dir {
+  my $self = shift;
+  if (@_) {
+    $self->{native_bin_dir} = $_[0];
+    return $self;
+  }
+  else {
+    return $self->{native_bin_dir};
+  }
+}
+
 sub include_dirs {
   my $self = shift;
   if (@_) {
@@ -105,6 +171,17 @@ sub ldflags {
   }
 }
 
+sub native_src_dir {
+  my $self = shift;
+  if (@_) {
+    $self->{native_src_dir} = $_[0];
+    return $self;
+  }
+  else {
+    return $self->{native_src_dir};
+  }
+}
+
 sub lib_dirs {
   my $self = shift;
   if (@_) {
@@ -188,6 +265,48 @@ sub new {
     $self->exported_funcs([]);
   }
 
+  # file_optional
+  unless (defined $self->{file_optional}) {
+    $self->file_optional(0);
+  }
+  
+  # file
+  if (!$self->file_optional && !defined $self->{file}) {
+    confess('file field must be specified.');
+  }
+  
+  if (defined $self->{file}) {
+    my $config_file = $self->{file};
+    my $config_file_without_ext = $config_file;
+    $config_file_without_ext =~ s/\.config$//;
+    
+    my $native_include_dir = "$config_file_without_ext.native/include";
+    my $native_src_dir = "$config_file_without_ext.native/src";
+    my $native_lib_dir = "$config_file_without_ext.native/lib";
+    my $native_bin_dir = "$config_file_without_ext.native/bin";
+    
+    $self->native_include_dir($native_include_dir);
+    $self->native_src_dir($native_src_dir);
+    $self->native_lib_dir($native_lib_dir);
+    $self->native_bin_dir($native_bin_dir);
+    
+  }
+
+  unless (defined $self->{class_name}) {
+    if (defined $self->{file}) {
+      my $config_file = $self->{file};
+      my $config_file_without_ext = $config_file;
+      $config_file_without_ext =~ s/\.config$//;
+      
+      my $module_file = "$config_file_without_ext.spvm";
+      my $module_source = SPVM::Builder::Util::slurp_binary($module_file);
+      if ($module_source =~ /\bclass\s+([\w:]+)/s) {
+        my $class_name = $1;
+        $self->{class_name} = $class_name;
+      }
+    }
+  }
+  
   # include_dirs
   unless (defined $self->{include_dirs}) {
     $self->include_dirs([]);
@@ -276,7 +395,7 @@ sub new {
 sub new_c {
   my $class = shift;
   
-  my $self = SPVM::Builder::Config->new;
+  my $self = SPVM::Builder::Config->new(@_);
   
   return $self;
 }
@@ -284,7 +403,7 @@ sub new_c {
 sub new_c99 {
   my $class = shift;
   
-  my $self = SPVM::Builder::Config->new_c;
+  my $self = SPVM::Builder::Config->new_c(@_);
   
   # C99
   $self->set_std('c99');
@@ -295,7 +414,7 @@ sub new_c99 {
 sub new_cpp {
   my $class = shift;
   
-  my $self = SPVM::Builder::Config->new;
+  my $self = SPVM::Builder::Config->new(@_);
   
   # CC
   $self->cc('g++');
@@ -309,7 +428,7 @@ sub new_cpp {
 sub new_cpp11 {
   my $class = shift;
   
-  my $self = SPVM::Builder::Config->new_cpp;
+  my $self = SPVM::Builder::Config->new_cpp(@_);
   
   # C++11
   $self->set_std('c++11');
@@ -648,6 +767,83 @@ Get and set the option for optimization of the linker such as C<-O3>, C<-O2>, C<
 
 The default is C<-O2>.
 
+=head2 file
+
+  my $file = $config->file;
+  $config->file($file);
+
+Get and set the config file path.
+
+=head2 file_optional
+
+  my $file_optional = $config->file_optional;
+  $config->file_optional($file_optional);
+
+Get and set the L<"file"> field is optional in L<"new"> method.
+
+Default is C<0>.
+
+B<Examples:>
+
+  my $config = SPVM::Builder::Config->new(file_optional => 1);
+
+=head2 class_name
+
+  my $class_name = $config->class_name;
+  $config->class_name($class_name);
+
+Get and set the class name.
+
+This is automatically decided by L<"file"> field when C<"new"> method is called.
+
+For example L<"file"> is C</path/SPVM/Foo.config>, C<class_name> becomes C<SPVM::Foo>.
+
+Because This is parsed from C</path/SPVM/Foo.spvm>, the module file must be exist if C<file> field is specified.
+
+=head2 native_include_dir
+
+  my $native_include_dir = $config->native_include_dir;
+  $config->native_include_dir($native_include_dir);
+
+Get and set the native C<include> directory.
+
+This is automatically decided by L<"file"> field when C<"new"> method is called.
+
+For example L<"file"> is C</path/SPVM/Foo.config>, C<native_include_dir> becomes C</path/SPVM/Foo.native/include>
+
+=head2 native_src_dir
+
+  my $native_src_dir = $config->native_src_dir;
+  $config->native_src_dir($native_src_dir);
+
+Get and set the native C<src> directory. This is automatically decided by L<"file"> field when C<"new"> method is called.
+
+This is automatically decided by L<"file"> field when C<"new"> method is called.
+
+For example L<"file"> is C</path/SPVM/Foo.config>, C<native_include_dir> becomes C</path/SPVM/Foo.native/src>
+
+=head2 native_lib_dir
+
+  my $native_lib_dir = $config->native_lib_dir;
+  $config->native_lib_dir($native_lib_dir);
+
+Get and set the native C<lib> directory.
+
+This is automatically decided by L<"file"> field when C<"new"> method is called.
+
+For example L<"file"> is C</path/SPVM/Foo.config>, C<native_lib_dir> becomes C</path/SPVM/Foo.native/lib>
+
+=head2 native_bin_dir
+
+  my $native_bin_dir = $config->native_bin_dir;
+  $config->native_bin_dir($native_bin_dir);
+
+Get and set the native C<bin> directory.
+
+This is automatically decided by L<"file"> field when C<"new"> method is called.
+
+For example L<"file"> is C</path/SPVM/Foo.config>, C<native_bin_dir> becomes C</path/SPVM/Foo.native/bin>
+
 =head2 force
 
   my $force = $config->force;
@@ -668,13 +864,18 @@ The default is C<1>.
 
 =head2 new
 
-  my $config = SPVM::Builder::Config->new;
+  my $config = SPVM::Builder::Config->new(file => $config_file);
   
 Create L<SPVM::Builder::Config> object.
 
+B<Examples:>
+  
+  # Foo/Bar.config
+  my $config = SPVM::Builder::Config->new(file => __FILE__);
+
 =head2 new_c
   
-  my $config = SPVM::Builder::Config->new_c;
+  my $config = SPVM::Builder::Config->new_c(file => $config_file);
 
 Create default build config with C settings. This is L<SPVM::Builder::Config> object.
 
@@ -682,15 +883,25 @@ If you want to use the specific C version, use C<set_std> method.
 
   $config->set_std('c99');
 
+B<Examples:>
+  
+  # Foo/Bar.config
+  my $config = SPVM::Builder::Config->new_c(file => __FILE__);
+
 =head2 new_c99
   
-  my $config = SPVM::Builder::Config->new_c99;
+  my $config = SPVM::Builder::Config->new_c99(file => $config_file);
 
 Create default build config with C99 settings. This is L<SPVM::Builder::Config> object.
 
+B<Examples:>
+  
+  # Foo/Bar.config
+  my $config = SPVM::Builder::Config->new_c99(file => __FILE__);
+
 =head2 new_cpp
   
-  my $config = SPVM::Builder::Config->new_cpp;
+  my $config = SPVM::Builder::Config->new_cpp(file => $config_file);
 
 Create default build config with C++ settings. This is L<SPVM::Builder::Config> object.
 
@@ -698,12 +909,22 @@ If you want to use the specific C++ version, use C<set_std> method.
 
   $config->set_std('c++11');
 
+B<Examples:>
+  
+  # Foo/Bar.config
+  my $config = SPVM::Builder::Config->new_cpp(file => __FILE__);
+
 =head2 new_cpp11
   
-  my $config = SPVM::Builder::Config->new_cpp11;
+  my $config = SPVM::Builder::Config->new_cpp11(file => __FILE__);
 
 Create default build config with C++11 settings. This is L<SPVM::Builder::Config> object.
 
+B<Examples:>
+  
+  # Foo/Bar.config
+  my $config = SPVM::Builder::Config->new_cpp11(file => __FILE__);
+
 =head2 set_std
 
   $config->set_std($std);
