@@ -106,22 +106,22 @@ sub build_exe_file {
     exit(255);
   }
 
-  # Create precompile C sources
+  # Create precompile C source_files
   $self->create_precompile_csources;
   
-  # Compile precompile C sources
+  # Compile precompile C source_files
   $self->compile_precompile_csources;
 
-  # Compile precompile C sources
+  # Compile precompile C source_files
   my ($native_object_files) = $self->compile_native_csources;
 
-  # Create SPMV module C sources
+  # Create SPMV module C source_files
   $self->create_spvm_module_csources;
 
-  # Compile SPVM compiler and runtime C sources
+  # Compile SPVM compiler and runtime C source_files
   $self->compile_spvm_module_csources;
 
-  # Compile SPVM compiler and runtime C sources
+  # Compile SPVM compiler and runtime C source_files
   $self->compile_spvm_compiler_and_runtime_csources;
 
   # Create bootstrap C source
@@ -350,7 +350,7 @@ sub compile_spvm_module_csources {
   my $class_names = $builder->get_class_names;
   
   # Config
-  my $config = SPVM::Builder::Config->new_c99;
+  my $config = SPVM::Builder::Config->new_c99(file_optional => 1);
 
   # Optimize
   my $optimize = $self->optimize;
@@ -496,7 +496,7 @@ EOS
   SPVM_OP_build_use(compiler, op_use_start, op_type_start, NULL, 0);
   SPVM_LIST_push(compiler->op_use_stack, op_use_start);
   
-  // Set module sources
+  // Set module source_files
 EOS
   
   for my $class_name (@$class_names) {
@@ -649,7 +649,7 @@ sub compile_bootstrap_csource {
   my $build_dir = $self->builder->build_dir;
   
   # Config
-  my $config = SPVM::Builder::Config->new_c99;
+  my $config = SPVM::Builder::Config->new_c99(file_optional => 1);
   
   # Optimize
   my $optimize = $self->optimize;
@@ -738,7 +738,7 @@ sub compile_spvm_compiler_and_runtime_csources {
   my @spvm_compiler_and_runtime_src_files = map { "$spvm_compiler_and_runtime_src_dir/$_" } @SPVM_RUNTIME_SRC_BASE_NAMES;
   
   # Config
-  my $config = SPVM::Builder::Config->new_c99;;
+  my $config = SPVM::Builder::Config->new_c99(file_optional => 1);
   
   # Default include path
   $config->add_ccflags("-Iblib/lib/SPVM/Builder/include");
@@ -816,7 +816,7 @@ sub link {
   my $class_name_rel_file = SPVM::Builder::Util::convert_class_name_to_rel_file($target_perl_class_name);
   push @$object_files, glob "$build_work_object_dir/$class_name_rel_file.boot.o";
   
-  my $config = SPVM::Builder::Config->new_c99;
+  my $config = SPVM::Builder::Config->new_c99(file_optional => 1);
   
   # CBuilder configs
   my $output_file = $self->{output_file};
